@@ -23,12 +23,12 @@ package Algorithm::Evolutionary::Fitness::Base;
 
 use Carp;
 
-our ($VERSION) = ( '$Revision: 1.4 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.6 $ ' =~ /(\d+\.\d+)/ );
 
 
 =head2 new()
 
-Initializes common variables, like the number of evaluations
+Initializes common variables, like the number of evaluations. Cache is not initialized.
 
 =cut 
 
@@ -49,6 +49,7 @@ Called from new, initializes the evaluations counter.
 sub initialize {
   my $self = shift;
   $self->{_counter} = 0; 
+  $self->{_cache} = {};
 }
 
 
@@ -74,7 +75,7 @@ derived clases
 =cut
 
 sub _apply {
-  carp "You should have overloaded this\n";
+  croak "You should have overloaded this\n";
 }
 
 
@@ -87,7 +88,29 @@ collecting stats
 
 sub evaluations {
   my $self = shift;
-  return $self->{_counter};
+  return $self->{'_counter'};
+}
+
+=head2 reset_evaluations() 
+
+Sets to 0 the number of evaluations; useful for repeated use of the fitness object
+
+=cut
+
+sub reset_evaluations {
+  my $self = shift;
+  $self->{'_counter'} = 0;
+}
+
+=head2 cache() 
+
+Returns a reference to the internal evaluations cache. Not very encapsulated, but...
+
+=cut
+
+sub cache {
+    my $self = shift;
+    return $self->{'cache'};
 }
 
 =head1 Known subclasses
@@ -110,6 +133,14 @@ L<Algorithm::Evolutionary::Fitness::wP_Peaks>
 
 L<Algorithm::Evolutionary::Fitness::Knapsack>
 
+=item * 
+
+L<Algorithm::Evolutionary::Fitness::ECC>
+
+=item * 
+
+L<Algorithm::Evolutionary::Fitness::Royal_Road>
+
 =back
 
 =head1 Copyright
@@ -117,10 +148,10 @@ L<Algorithm::Evolutionary::Fitness::Knapsack>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/06/18 17:18:11 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Base.pm,v 1.4 2008/06/18 17:18:11 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/04 18:26:01 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Base.pm,v 1.6 2009/02/04 18:26:01 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.4 $
+  $Revision: 1.6 $
   $Name $
 
 =cut
