@@ -1,34 +1,30 @@
 use strict; # -*- cperl -*-
 use warnings;
 
-use lib qw( ../../../../lib );
-
 =head1 NAME
 
 Algorithm::Evolutionary::Fitness::ECC - Error Correcting codes problem generator
 
 =head1 SYNOPSIS
 
-    my $number_of_codewords = 10;
-    my $min_distance = 1;
-    my $p_peaks = Algorithm::Evolutionary::Fitness::ECC->new( $number_of_codewords, $min_distance );
+    my $number_of_peaks = 100;
+    my $number_of_bits = 32;
+    my $p_peaks = Algorithm::Evolutionary::Fitness::P_Peaks->new( $number_of_peaks, $number_of_bits );
 
 =head1 DESCRIPTION
 
-Extracted from article "Effects of scale-free and small-world topologies on binary coded self-adaptive CEA", by Giacobini et al [Ga]. Quoting:
+Extracted from article "Effects of scale-free and small-world topologies on binary coded self-adaptive CEA", by Giacobini et al. Quoting:
 "                                                    The ECC problem was presented in
-[MW]. We will consider a three-tuple (n, M, d), where n is the length of each codeword
+[13]. We will consider a three-tuple (n, M, d), where n is the length of each codeword
 (number of bits), M is the number of codewords, and d is the minimum Hamming
 distance between any pair of codewords. Our objective will be to find a code which
 has a value for d as large as possible (reflecting greater tolerance to noise and errors),
 given previously fixed values for n and M . The problem we have studied is a simplified
-version of that in [MW]. In our case we search half of the codewords (M/2) that will
+version of that in [13]. In our case we search half of the codewords (M/2) that will
 compose the code, and the other half is made up by the complement of the codewords
 computed by the algorithm"
 
-[Ga] Mario Giacobini, Mike Preuss, Marco Tomassini: Effects of Scale-Free and Small-World Topologies on Binary Coded Self-adaptive CEA. EvoCOP 2006: 86-98.
-
-[MW] F. J. MacWilliams and N. J. A. Sloane. The Theory of Error-Correcting Codes. North-
+[13] F. J. MacWilliams and N. J. A. Sloane. The Theory of Error-Correcting Codes. North-
     Holland, Amsterdam, 1977.
 
 
@@ -38,8 +34,9 @@ computed by the algorithm"
 
 package Algorithm::Evolutionary::Fitness::ECC;
 
-our ($VERSION) = ( '$Revision: 3.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.3 $ ' =~ /(\d+\.\d+)/ ) ;
 
+use String::Random;
 use Carp qw(croak);
 
 use lib qw(../../.. ../.. ..);
@@ -49,7 +46,7 @@ use Algorithm::Evolutionary::Utils qw(hamming);
 
 =head2 new
 
-Creates a new instance of the problem, with the said number of bits and peaks
+    Creates a new instance of the problem, with the said number of bits and peaks
 
 =cut 
 
@@ -76,7 +73,7 @@ sub _really_apply {
   return $self->ecc( @_ );
 }
 
-=head2 ecc
+=head2 p_peaks
 
 Applies the instantiated problem to a string
 
@@ -108,10 +105,10 @@ sub ecc {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 10:25:49 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ECC.pm,v 3.2 2009/07/24 10:25:49 jmerelo Exp $ 
+  CVS Info: $Date: 2008/10/27 18:00:44 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ECC.pm,v 1.3 2008/10/27 18:00:44 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 1.3 $
   $Name $
 
 =cut
