@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Fitness::P_Peaks - P Peaks problem generator
+Algorithm::Evolutionary::Fitness::P_Peaks - P Peaks problem generator
 
 =head1 SYNOPSIS
 
@@ -13,7 +13,7 @@ use warnings;
 
 =head1 DESCRIPTION
 
-P_Peaks fitness function, that measures the distance to a series of peaks
+P_Peaks fitness function; optimizes the distance to the closest in a series of peaks
 
 =head1 METHODS
 
@@ -21,14 +21,17 @@ P_Peaks fitness function, that measures the distance to a series of peaks
 
 package Algorithm::Evolutionary::Fitness::P_Peaks;
 
+our $VERSION = ( '$Revision: 1.11 $ ' =~ /(\d+\.\d+)/ ) ;
+
 use String::Random;
+use Carp;
 
 use lib qw(../../.. ../.. ..);
 
-use base qw(Algorithm::Evolutionary::Fitness::Base);
+use base qw(Algorithm::Evolutionary::Fitness::String);
 use Algorithm::Evolutionary::Utils qw(hamming);
 
-=head2 new
+=head2 new( $peaks, $bits )
 
     Creates a new instance of the problem, with the said number of bits and peaks
 
@@ -37,14 +40,16 @@ use Algorithm::Evolutionary::Utils qw(hamming);
 sub new {
   my $class = shift;
   my ($peaks, $bits ) = @_;
-
+  croak "No peaks"  if !$peaks;
+  croak "Too few bits" if !$bits;
+  my $self = $class->SUPER::new();
   #Generate peaks
   my $generator = new String::Random;
   my @peaks;
   my $regex = "\[01\]{$bits}";
-  my $self = { bits => $bits,
-	       generator => $generator,
-	       regex => $regex };
+  for my $s qw( bits generator regex ) {
+      eval "\$self->{'$s'} = \$$s";
+  }
   for my $p ( 1..$peaks ) {
     push( @peaks, $generator->randregex($regex));
   }
@@ -54,7 +59,7 @@ sub new {
   return $self;
 }
 
-=head2 random_string
+=head2 random_string()
 
 Returns random string in the same style than the peaks. Useful for testing
 
@@ -65,59 +70,47 @@ sub random_string {
     return $self->{'generator'}->randregex($self->{'regex'});
 }
 
-=head2 _apply
+=head2 _really_apply( $string )
 
-Applies the instantiated problem to a chromosome
+Applies the instantiated problem to a chromosome. Intended for internal use.
 
 =cut
 
-sub _apply {
-    my $self = shift;
-    my $individual = shift;
-    return $self->p_peaks( $individual->{_str})/$self->{'bits'} ;
+sub _really_apply {
+  my $self = shift;
+  return $self->p_peaks( @_ )/$self->{'bits'} ;
 }
 
-=head2 p_peaks
+=head2 p_peaks( $string )
 
 Applies the instantiated problem to a string
 
 =cut
 
-our %cache;
-
 sub p_peaks {
     my $self = shift;
     my @peaks = @{$self->{'peaks'}};
-    my $string = shift;
-    if ( $cache{$string} ) {
-	return $cache{$string};
+    my $string = shift || croak "No string!";
+    my $cache = $self->{'_cache'};
+    if ( $cache->{$string} ) {
+	return $cache->{$string};
     }
     my $bits = $self->{'bits'};
     my @distances = sort {$b <=> $a}  map($bits - hamming( $string, $_), @peaks);
-    $cache{$string} = $distances[0];
-    return $cache{$string};
+    $cache->{$string} = $distances[0];
+    return $cache->{$string};
 
 }
 
-=head2 cached_evals
-
-Returns the number of keys in the evaluation cache
-
-=cut
-
-sub cached_evals {
-    return scalar keys %cache;
-}
-
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/06/17 11:38:36 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/P_Peaks.pm,v 1.7 2008/06/17 11:38:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/10/27 18:00:44 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/P_Peaks.pm,v 1.11 2008/10/27 18:00:44 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.7 $
+  $Revision: 1.11 $
   $Name $
 
 =cut
