@@ -1,12 +1,10 @@
 use strict; #-*-cperl-*-
 use warnings;
 
-use lib qw(../../../../lib);
-
 =head1 NAME
 
     Algorithm::Evolutionary::Individual::Bit_Vector - Classic bitstring individual for evolutionary computation; 
-                 usually called chromosome, and using a different implementation from Algorithm::Evolutionary::Individual::BitString
+                 usually called I<chromosome>, and using a different implementation from L<Algorithm::Evolutionary::Individual::BitString>
 
 
 =head1 SYNOPSIS
@@ -35,7 +33,7 @@ use lib qw(../../../../lib);
     print tied( @vector )->asXML();
 
     print $indi3->asString(); #Prints the individual
-    print $indi3->asXML() #Prints it as XML. See L<Algorithm::Evolutionary::XML>
+    print $indi3->asXML() #Prints it as XML. See 
     print $indi3->as_yaml() #Change of convention, I know...
 
 =head1 Base Class
@@ -54,7 +52,7 @@ use Carp;
 use Bit::Vector;
 use String::Random; # For initial string generation
 
-our ($VERSION) =  ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) =  ( '$Revision: 1.6 $ ' =~ / (\d+\.\d+)/ );
 
 use base 'Algorithm::Evolutionary::Individual::Base';
 
@@ -75,25 +73,18 @@ sub new {
     my $class = shift; 
     my $self = Algorithm::Evolutionary::Individual::Base::new( $class );
     my $arg = shift || { length => 16};
-    if ( $arg =~ /^\d+$/ ) { #It's a number
-      $self->{'_bit_vector'} = _create_bit_vector( $arg );
-    } elsif ( $arg->{'length'} ) {
-      $self->{'_bit_vector'} = _create_bit_vector( $arg->{'length'} );
+    if ( $arg->{'length'} ) {
+	my $length = $arg->{'length'};
+	my $rander = new String::Random;
+	my $hex_string = $rander->randregex("[0-9A-F]{".int($length/4)."}");
+	$self->{'_bit_vector'} = Bit::Vector->new_Hex( $length, $hex_string );
     } elsif ( $arg->{'string'} ) {
-      $self->{'_bit_vector'} = 
-	Bit::Vector->new_Bin( length($arg->{'string'}), $arg->{'string'} );
-    } 
-    croak "Incorrect creation options" if !$self->{'_bit_vector'};
+	$self->{'_bit_vector'} = 
+	    Bit::Vector->new_Bin( length($arg->{'string'}), $arg->{'string'} );
+    }
     return $self;
 }
 
-sub _create_bit_vector {
-   my $length = shift || croak "No length!";
-   my $rander = new String::Random;
-   my $hex_string = $rander->randregex("[0-9A-F]{".int($length/4)."}");
-   return Bit::Vector->new_Hex( $length, $hex_string );
-}
-
 sub TIEARRAY {
   my $class = shift; 
   my $self = { _bit_vector => Bit::Vector->new_Bin(scalar( @_), join("",@_)) };
@@ -223,19 +214,16 @@ sub SPLICE {
   my $offset = shift;
   my $bits = shift;
   my $new_vector;
-  my $slice = Bit::Vector->new($bits);
-  my $size =  $self->{'_bit_vector'}->Size();
-  $slice->Interval_Copy(  $self->{'_bit_vector'}, 0, $size-$offset-$bits,  $bits );
   if ( @_ ) {
     $new_vector =  Bit::Vector->new_Bin(scalar(@_), join("",@_));
-    $self->{'_bit_vector'}->Interval_Substitute( $new_vector, 
-						 $size-$offset-$bits, 0 , 0, 
-						 $new_vector->Size() );
+    return split(//, 
+		 $self->{'_bit_vector'}->Interval_Substitute( $new_vector, 0, $new_vector->Size()|| 0, 
+							      $offset, $bits  )->to_Bin());
   } else {
-    $self->{'_bit_vector'}->Interval_Substitute( Bit::Vector->new(0), $size-$offset-$bits, $bits,
-						 0, 0  );
-  } 
-  return split(//,$slice->to_Bin());
+    $new_vector = Bit::Vector->new($bits);
+    $new_vector->Interval_Copy(  $self->{'_bit_vector'}, $offset, 0, $bits );
+    return split(//,$new_vector->to_Bin());
+  }
 
 }
 
@@ -250,10 +238,10 @@ sub FETCHSIZE {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/12/19 21:39:12 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Bit_Vector.pm,v 3.1 2010/12/19 21:39:12 jmerelo Exp $ 
+  CVS Info: $Date: 2008/09/12 18:31:02 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Bit_Vector.pm,v 1.6 2008/09/12 18:31:02 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.6 $
   $Name $
 
 =cut
