@@ -1,9 +1,11 @@
-use strict;
+use strict; #-*-cperl-*-
 use warnings;
 
+use lib qw( ../../lib ../../../lib ../../../../lib);
+
 =head1 NAME
 
-  Algorithm::Evolutionary::Op::Bitflip - BitFlip mutation
+  Algorithm::Evolutionary::Op::Bitflip - Bit-flip mutation
 
 =head1 SYNOPSIS
 
@@ -32,11 +34,9 @@ does not need a rate
 
 =cut
 
-
 package Algorithm::Evolutionary::Op::Bitflip;
 
-our ($VERSION) = ( '$Revision: 1.2 $ ' =~ /(\d+\.\d+)/ );
-
+our ($VERSION) = ( '$Revision: 1.5 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 use Clone::Fast qw(clone);
@@ -45,9 +45,9 @@ use Algorithm::Evolutionary::Op::Base;
 our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 #Class-wide constants
-our $APPLIESTO =  'Algorithm::Evolutionary::Individual::BitString';
 our $ARITY = 1;
-=head2 new
+
+=head2 new( [$how_many] [,$priority] )
 
 Creates a new mutation operator with a bitflip application rate, which defaults to 0.5,
 and an operator application rate (general for all ops), which defaults to 1.
@@ -64,7 +64,7 @@ sub new {
   return $self;
 }
 
-=head2 create
+=head2 create()
 
 Creates a new mutation operator.
 
@@ -77,11 +77,11 @@ sub create {
   return $self;
 }
 
-=head2 apply
+=head2 apply( $chromosome )
 
 Applies mutation operator to a "Chromosome", a bitstring, really. Can be
-applied only to I<victims> with the C<_str> instance variable; but
-it checks before application that both operands are of type
+applied only to I<victims> composed of [0,1] atoms, independently of representation; but 
+it checks before application that the operand is of type
 L<BitString|Algorithm::Evolutionary::Individual::BitString>.
 
 =cut
@@ -90,13 +90,22 @@ sub apply ($;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
 #  my $victim = $arg->clone();
-  my $victim = clone( $arg );
-  croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
-  for ( my $i = 0; $i < $self->{_howMany}; $i++ ) {
-	my $rnd = int (rand( length( $victim->{_str} ) ));
-	$victim->Atom( $rnd, $victim->Atom( $rnd )?0:1 );
+  my $victim; 
+  if ( (ref $arg ) =~ /BitString/ ) {
+    $victim = clone( $arg );
+  } else {
+    $victim = $arg->clone();
   }
-  $victim->Fitness(undef); #Invalidate fitness
+  my $size =  $victim->size();
+#  croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
+  croak "Too many changes" if $self->{_howMany} >= $size;
+  my @bits = 0..$size; # Hash with all bits
+  for ( my $i = 0; $i < $self->{_howMany}; $i++ ) {
+      my $rnd = int (rand( @bits ));
+      my $who = splice(@bits, $rnd, 1 );
+      $victim->Atom( $who, $victim->Atom( $who )?0:1 );
+  }
+  $victim->{'_fitness'} = undef ;
   return $victim;
 }
 
@@ -105,10 +114,10 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/06/26 11:37:43 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Bitflip.pm,v 1.2 2008/06/26 11:37:43 jmerelo Exp $ 
+  CVS Info: $Date: 2008/10/02 05:56:55 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Bitflip.pm,v 1.5 2008/10/02 05:56:55 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.2 $
+  $Revision: 1.5 $
   $Name $
 
 =cut
