@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-  Algorithm::Evolutionary::Op::Crossover - n-point crossover
+Algorithm::Evolutionary::Op::Crossover - n-point crossover
     operator; puts a part of the second operand into the first
     operand; can be 1 or 2 points.
              
@@ -19,7 +19,7 @@ use warnings;
   my $op3 = Algorithm::Evolutionary::Op::Base->fromXML( $xmlStr3 );
   print $op3->asXML(), "\n";
 
-  #Apply to 2 Individuals. Could be String.
+  #Apply to 2 Individuals of the String class
   my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
   my $indi2 = $indi->clone();
   my $indi3 = $indi->clone();
@@ -48,21 +48,25 @@ would be  L<Algorithm::Evolutionary::Op::VectorCrossover|Op::VectorCrossover>
 
 package Algorithm::Evolutionary::Op::Crossover;
 
-our ($VERSION) = ( '$Revision: 1.2 $ ' =~ /(\d+\.\d+)/ );
+use lib qw(../../..);
+
+our ($VERSION) = ( '$Revision: 1.7 $ ' =~ /(\d+\.\d+)/ );
 
 use Clone::Fast qw(clone);
 use Carp;
 
-use Algorithm::Evolutionary::Op::Base;
-our @ISA = ('Algorithm::Evolutionary::Op::Base');
+use base 'Algorithm::Evolutionary::Op::Base';
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 2;
 
-=head2 new
+=head2 new( [$options_hash] [, $operation_priority] )
 
-Creates a new n-point crossover operator, with 2 as the default number of points
+Creates a new n-point crossover operator, with 2 as the default number
+of points, that is, the default would be
+    my $options_hash = { numPoints => 2 };
+    my $priority = 1;
 
 =cut
 
@@ -70,11 +74,11 @@ sub new {
   my $class = shift;
   my $hash = { numPoints => shift || 2 };
   my $rate = shift || 1;
-  my $self = Algorithm::Evolutionary::Op::Base::new( __PACKAGE__, $rate, $hash );
+  my $self = Algorithm::Evolutionary::Op::Base::new( $class, $rate, $hash );
   return $self;
 }
 
-=head2 create
+=head2 create( [$num_points] )
 
 Creates a new 1 or 2 point crossover operator. But this is just to have a non-empty chromosome
 Defaults to 2 point
@@ -89,7 +93,7 @@ sub create {
   return $self;
 }
 
-=head2 apply
+=head2 apply( $chromsosome_1, $chromosome_2 )
 
 Applies xover operator to a "Chromosome", a string, really. Can be
 applied only to I<victims> with the C<_str> instance variable; but
@@ -97,8 +101,7 @@ it checks before application that both operands are of type
 L<BitString|Algorithm::Evolutionary::Individual::String>.
 
 Changes the first parent, and returns it. If you want to change both
-parents at the same time, check L<Algorithm::Evolutionary::Op:QuadXOver|Algorithm::Evolutionary::Op:QuadXOver>
-
+parents at the same time, check L<QuadXOver|Algorithm::Evolutionary::Op:QuadXOver>
 
 =cut
 
@@ -108,8 +111,8 @@ sub  apply ($$$){
 #  my $victim = $arg->clone();
   my $victim = clone( $arg );
   my $victim2 = shift || croak "No victim here!";
-  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
-  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
+#  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
+#  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
   my $pt1 = int( rand( $minlen ) );
@@ -121,7 +124,7 @@ sub  apply ($$$){
   }
   
   substr( $victim->{_str}, $pt1, $range ) = substr( $victim2->{_str}, $pt1, $range );
-  $victim->Fitness( undef );
+  $victim->{'_fitness'} = undef;
   return $victim; 
 }
 
@@ -130,10 +133,10 @@ sub  apply ($$$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/06/26 11:37:43 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 1.2 2008/06/26 11:37:43 jmerelo Exp $ 
+  CVS Info: $Date: 2008/11/08 18:25:54 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 1.7 2008/11/08 18:25:54 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.2 $
+  $Revision: 1.7 $
   $Name $
 
 =cut
