@@ -47,11 +47,9 @@ would be  L<Algorithm::Evolutionary::Op::VectorCrossover|Op::VectorCrossover>
 
 package Algorithm::Evolutionary::Op::Gene_Boundary_Crossover;
 
-use lib qw(../../..);
+our ($VERSION) = ( '$Revision: 1.1 $ ' =~ /(\d+\.\d+)/ );
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
-
-use Clone qw(clone);
+use Clone::Fast qw(clone);
 use Carp;
 
 use base 'Algorithm::Evolutionary::Op::Base';
@@ -141,10 +139,10 @@ sub  apply ($$$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Gene_Boundary_Crossover.pm,v 3.2 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/11/02 19:21:57 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Gene_Boundary_Crossover.pm,v 1.1 2008/11/02 19:21:57 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 1.1 $
   $Name $
 
 =cut
