@@ -1,25 +1,14 @@
 use strict; #-*-cperl-*-
 use warnings;
 
-use lib qw(../../..);
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Novelty_Mutation - Mutation guaranteeing new individual is not in the population
+  Algorithm::Evolutionary::Op::Novelty_Mutation - Mutation guaranteeing new individual is not in the population
 
 =head1 SYNOPSIS
 
-  my $mmdp = new  Algorithm::Evolutionary::Fitness::MMDP;
-  my $bits = 36;
-  my @population;
-  for ( 1..100 ) { #Create and evaluate a population
-    my $indi = new Algorithm::Evolutionary::Individual::BitString $bits;
-    $indi->evaluate( $mmdp );
-    push @population, $indi;
-  }
-  my $nm = new Algorithm::Evolutionary::Op::Novelty_Mutation $mmdp->{'_cache'}; #Initialize using cache
-  $nm->apply($population[$i]);
- 
+  my $op = new Algorithm::Evolutionary::Op::Novelty_Mutation $ref_to_population_hash; #The population hash can be obtained from some fitness functions
+
 =head1 Base Class
 
 L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
@@ -36,17 +25,18 @@ hash, and discarded if they are already in the population.
 
 package Algorithm::Evolutionary::Op::Novelty_Mutation;
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our ($VERSION) = ( '$Revision: 1.3 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
-use Clone qw(clone);
+use Clone::Fast qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 #Class-wide constants
 our $ARITY = 1;
 
-=head2 new( $ref_to_population_hash [,$priority] )
+=head2 new( [$ref_to_population_hash] [,$priority] )
 
 Creates a new mutation operator with an operator application rate
 (general for all ops), which defaults to 1, and stores the reference
@@ -76,6 +66,7 @@ L<BitString|Algorithm::Evolutionary::Individual::BitString>.
 sub apply ($;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
+#  my $victim = $arg->clone();
   my $test_clone; 
   my $size =  $arg->size();
   for ( my $i = 0; $i < $size; $i++ ) {
@@ -85,7 +76,7 @@ sub apply ($;$){
       $test_clone = $arg->clone();
     }
     $test_clone->Atom( $i, $test_clone->Atom( $i )?0:1 );
-    last if !$self->{'_population_hashref'}->{$test_clone->Chrom()}; #Exit if not found in the population
+    last if !$self->{'_population_hashref'}->{$test_clone->Chrom()};
   }
   if ( $test_clone->Chrom() eq $arg->Chrom() ) { # Nothing done, zap
     for ( my $i = 0; $i < $size; $i++ ) {
@@ -101,10 +92,10 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Novelty_Mutation.pm,v 3.1 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/10/03 16:32:30 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Novelty_Mutation.pm,v 1.3 2008/10/03 16:32:30 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.3 $
   $Name $
 
 =cut
