@@ -3,14 +3,13 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Storing - Applies the op and keeps the result
+  Algorithm::Evolutionary::Op::Storing - Applies the op and keeps the result
 
 =head1 SYNOPSIS
 
   my %visited_population_hash;
 
-  #Create from scratch with default operator rate
-  my $op = new Algorithm::Evolutionary::Op::Bitflip 2; 
+  my $op = new Algorithm::Evolutionary::Op::Bitflip 2; #Create from scratch with default rate
 
   my $stored_op = new Algorithm::Evolutionary::Op::Storing ( $op, \%visited_population_hash );
 
@@ -21,10 +20,8 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-Applies an operator and stores the result in a hash (can be a tied
-database), so that the whole population is stored. It creates an
-operator whose results are cached, which could be useful for expensive
-operators. 
+Applies an operator and stores the result in a hash (can be a tied database),
+so that the whole population is kept
 
 =head1 METHODS 
 
@@ -32,11 +29,10 @@ operators.
 
 package Algorithm::Evolutionary::Op::Storing;
 
-use lib qw(../../..);
-
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our ($VERSION) = ( '$Revision: 1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
+use Clone::Fast qw(clone);
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -80,10 +76,10 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Storing.pm,v 3.1 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/10/27 18:00:44 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Storing.pm,v 1.1 2008/10/27 18:00:44 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1 $
   $Name $
 
 =cut
